==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomStringList.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomStringList</code></p>
 */
public class DomStringList extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomStringList::<wbr/>DomStringList()</code></p>
     */
    public DomStringList(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomStringList instance);
    
    /**
     * <p>See <code>DomStringList::<wbr/>attributeComment()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeComment(){
        return attributeComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeComment_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>attributeExtraComment()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeExtraComment(){
        return attributeExtraComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeExtraComment_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>attributeId()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeId(){
        return attributeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>attributeNotr()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeNotr(){
        return attributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeNotr_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>clearAttributeComment()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeComment(){
        clearAttributeComment_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeComment_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>clearAttributeExtraComment()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeExtraComment(){
        clearAttributeExtraComment_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeExtraComment_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>clearAttributeId()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeId(){
        clearAttributeId_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeId_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>clearAttributeNotr()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeNotr(){
        clearAttributeNotr_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeNotr_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>elementString()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QStringList elementString(){
        return elementString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QStringList elementString_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>hasAttributeComment()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeComment(){
        return hasAttributeComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeComment_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>hasAttributeExtraComment()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeExtraComment(){
        return hasAttributeExtraComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeExtraComment_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>hasAttributeId()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeId(){
        return hasAttributeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>hasAttributeNotr()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeNotr(){
        return hasAttributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeNotr_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomStringList::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomStringList::<wbr/>setAttributeComment(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeComment(java.lang.@NonNull String a){
        setAttributeComment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeComment_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomStringList::<wbr/>setAttributeExtraComment(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeExtraComment(java.lang.@NonNull String a){
        setAttributeExtraComment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeExtraComment_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomStringList::<wbr/>setAttributeId(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeId(java.lang.@NonNull String a){
        setAttributeId_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeId_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomStringList::<wbr/>setAttributeNotr(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeNotr(java.lang.@NonNull String a){
        setAttributeNotr_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeNotr_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomStringList::<wbr/>setElementString(QStringList)</code></p>
     */
    @QtUninvokable
    public final void setElementString(java.util.@NonNull Collection<java.lang.@NonNull String> a){
        setElementString_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementString_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> a);
    
    /**
     * <p>See <code>DomStringList::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomStringList(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.7-sources.jar: io/qt/uic/ui4/DomStringList.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomStringList</p>
 */
public class DomStringList extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomStringList(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomStringList instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeComment(){
        return attributeComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeComment_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeExtraComment(){
        return attributeExtraComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeExtraComment_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeId(){
        return attributeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeId_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeNotr(){
        return attributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeNotr_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeComment(){
        clearAttributeComment_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeComment_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeExtraComment(){
        clearAttributeExtraComment_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeExtraComment_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeId(){
        clearAttributeId_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeId_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeNotr(){
        clearAttributeNotr_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeNotr_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList elementString(){
        return elementString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList elementString_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeComment(){
        return hasAttributeComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeComment_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeExtraComment(){
        return hasAttributeExtraComment_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeExtraComment_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeId(){
        return hasAttributeId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeId_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeNotr(){
        return hasAttributeNotr_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeNotr_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeComment(java.lang.String a){
        setAttributeComment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeComment_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setAttributeExtraComment(java.lang.String a){
        setAttributeExtraComment_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeExtraComment_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setAttributeId(java.lang.String a){
        setAttributeId_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeId_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setAttributeNotr(java.lang.String a){
        setAttributeNotr_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeNotr_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setElementString(java.util.Collection<java.lang.String> a){
        setElementString_native_cref_QStringList(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementString_native_cref_QStringList(long __this__nativeId, java.util.Collection<java.lang.String> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomStringList(QPrivateConstructor p) { super(p); } 
    
}
